<?php
/*
This file is part of Thomas Bley's moregroupware webmail2/calendar2/admin2 module. (tb-mgw)

More information:
-----------------

Simple Groupware Solutions Thomas Bley
Fichtenstr. 23
Germany, 85640 Putzbrunn

Contact:
--------

info@simple-groupware.de

http://www.simple-groupware.de


Copyright 2002-2003 Thomas Bley
tb-mgw is distributed under the terms of the GNU General Public License 

tb-mgw is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

tb-mgw is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with tb-mgw; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

// Date
// Moregroupware.org


function getTimeStamp($dateParts) {
    /** $dateParts[0] == <day of week>   Mon, Tue, Wed
    ** $dateParts[1] == <day of month>  23
    ** $dateParts[2] == <month>         Jan, Feb, Mar
    ** $dateParts[3] == <year>          1999
    ** $dateParts[4] == <time>          18:54:23 (HH:MM:SS)
    ** $dateParts[5] == <from GMT>      +0100
    ** $dateParts[6] == <zone>          (EDT)
    **
    ** NOTE:  In RFC 822, it states that <day of week> is optional.
    **        In that case, dateParts[0] would be the <day of month>
    **        and everything would be bumped up one.
    **/
   
    /* 
     * Simply check to see if the first element in the dateParts
     * array is an integer or not.
     *    Since the day of week is optional, this check is needed.
     *
     *    The old code used eregi('mon|tue|wed|thu|fri|sat|sun',
     *    $dateParts[0], $tmp) to find if the first element was the
     *    day of week or day of month. This is an expensive call
     *    (processing time) to have inside a loop. Doing it this way
     *    saves quite a bit of time for large mailboxes.
     *
     *    It is also quicker to call explode only once rather than
     *    the 3 times it was getting called by calling the functions
     *    getHour, getMinute, and getSecond.
     */

    if (! isset($dateParts[1])) {
        $dateParts[1] = '';
    }
    if (! isset($dateParts[2])) {
        $dateParts[2] = '';
    }
    if (! isset($dateParts[3])) {
        $dateParts[3] = '';
    }
    if (! isset($dateParts[4])) {
        $dateParts[4] = '';
    }
    if (! isset($dateParts[5])) {
        $dateParts[5] = '';
    }
    if (intval(trim($dateParts[0])) > 0) {
        $string = $dateParts[0] . ' ' . $dateParts[1] . ' ' .
                  $dateParts[2] . ' ' . $dateParts[3];
        return getGMTSeconds(strtotime($string), $dateParts[4]);
    }
    $string = $dateParts[0] . ' ' . $dateParts[1] . ' ' .
            $dateParts[2] . ' ' . $dateParts[3] . ' ' . $dateParts[4];
    if (isset($dateParts[5])) {
        return getGMTSeconds(strtotime($string), $dateParts[5]);
    } else {
        return getGMTSeconds(strtotime($string), '');
    }
}

function getGMTSeconds($stamp, $gmt) {
    global $invert_time;
    if (($gmt == 'Pacific') || ($gmt == 'PST')) {
        $gmt = '-0800'; 
    } else if (($gmt == 'EDT')) {
        $gmt = '-0400';
    } else if (($gmt == 'Eastern') || ($gmt == 'EST') || ($gmt == 'CDT')) {
        $gmt = '-0500';
    } else if (($gmt == 'Central') || ($gmt == 'CST') || ($gmt == 'MDT')) {
        $gmt = '-0600';
    } else if (($gmt == 'Mountain') || ($gmt == 'MST') || ($gmt == 'PDT')) {
        $gmt = '-0700';
    } else if ($gmt == 'BST') {
        $gmt = '+0100';
    } else if ($gmt == 'EET') {
        $gmt = '+0200';
    } else if ($gmt == 'GMT') {
        $gmt = '+0000';
    } else if ($gmt == 'HKT') {
        $gmt = '+0800';
    } else if ($gmt == 'IST') {
        $gmt = '+0200';
    } else if ($gmt == 'JST') {
        $gmt = '+0900';
    } else if ($gmt == 'KST') {
        $gmt = "+0900";
    } else if ($gmt == 'MET') {
        $gmt = '+0100';
    } else if ($gmt == 'MET DST' || $gmt == 'METDST') {
        $gmt = '+0200';
    }
    
    if (substr($gmt, 0, 1) == '-') {
        $neg = true;
        $gmt = substr($gmt, 1, strlen($gmt));
    } else if (substr($gmt, 0, 1) == '+') {
        $neg = false;
        $gmt = substr($gmt, 1, strlen($gmt));
    } else {
        $neg = false;
    }
    
    $gmt = substr($gmt, 0, 2);
    $gmt = $gmt * 3600;
    if ($neg == true) {
        $gmt = "-$gmt";
    } else {
        $gmt = "+$gmt";
    }
    
    /** now find what the server is at **/
    $current = date('Z', time());
    if ($invert_time) {
        $current = - $current;
    }
    $stamp = (int)$stamp - (int)$gmt + (int)$current;
    
    return $stamp;
}

function date_intl( $date_format, $stamp ) {

    $ret = str_replace( 'D', '$1', $date_format );
    $ret = str_replace( 'F', '$2', $ret );
    $ret = str_replace( 'l', '$4', $ret );
    $ret = str_replace( 'M', '$5', $ret );
    $ret = date( '$3'. $ret . '$3', $stamp ); // Workaround for a PHP 4.0.4 problem
    $ret = str_replace( '$1', substr( getDayName( date( 'w', $stamp ) ), 0, 3 ), $ret );
    $ret = str_replace( '$5', substr( getMonthName( date( 'm', $stamp ) ), 0, 3 ), $ret );    
    $ret = str_replace( '$2', getMonthName( date( 'm', $stamp ) ), $ret );
    $ret = str_replace( '$4', getDayName( date( 'w', $stamp ) ), $ret );
    $ret = str_replace( '$3', '', $ret );
    
    return( $ret );
}

function getDayName( $day_number ) {

    switch( $day_number ) {
    case 0:
        $ret = "Sunday";
        break;
    case 1:
        $ret = "Monday";
        break;
    case 2:
        $ret = "Tuesday";
        break;
    case 3:
        $ret = "Wednesday";
        break;
    case 4:
        $ret = "Thursday";
        break;
    case 5:
        $ret = "Friday";
        break;
    case 6:
        $ret = "Saturday";
        break;
    default:
        $ret = '';
    }
    return( $ret );
}

function getMonthName( $month_number ) {
    switch( $month_number ) {
     case '01':
        $ret = "January";
        break;
     case '02':
        $ret = "February";
        break;
     case '03':
        $ret = "March";
        break;
     case '04':
        $ret = "April";
        break;
     case '05':
        $ret = "May";
        break;
     case '06':
        $ret = "June";
        break;
     case '07':
        $ret = "July";
        break;
     case '08':
        $ret = "August";
        break;
     case '09':
        $ret = "September";
        break;
     case '10':
        $ret = "October";
        break;
     case '11':
        $ret = "November";
        break;
     case '12':
        $ret = "December";
        break;
     default:
        $ret = '';
    }
    return( $ret );
}

function getDateString( $stamp ) {

    global $invert_time;

    $now = time();
    
    $dateZ = date('Z', $now );
    if ($invert_time) {
        $dateZ = - $dateZ;
    }
    $midnight = $now - ($now % 86400) - $dateZ;
    
    if ($midnight < $stamp) {
        /* Today */
	$sep=$_SESSION["MGW"]->settings["set_hourminsep"];
        if ( $_SESSION["MGW"]->settings["set_timefmt"] == "12h" ) {
            $date_format = "g".$sep."i a";
        } else {
            $date_format = "G".$sep."i";
        }
    } else if ($midnight - 518400 < $stamp) {
        /* This week */
	$sep=$_SESSION["MGW"]->settings["set_hourminsep"];
        if ( $_SESSION["MGW"]->settings["set_timefmt"] == "12h" ) {
            $date_format = "D, g".$sep."i a";
        } else {
            $date_format = "D, G".$sep."i";
        }
    } else {
        /* before this week */
	$date_string = str_replace(array("m","d"),array("M","j"),$_SESSION["MGW"]->settings["set_datefmt"]);
	if ($date_string[0]=="Y") {$sep = ","; } else { $sep = ""; }
	$date_format = $date_string[0].$sep." ".$date_string[1]." ".$date_string[2];
    }
    
    return( date_intl( $date_format, $stamp ) );
}

function getDateString_full( $stamp ) {

	$date_string = str_replace(array("m","d"),array("M","j"),$_SESSION["MGW"]->settings["set_datefmt"]);

	if ($date_string[0]=="j") {$sep = "."; } else { $sep = ""; }
	$date_format = "l, ".$date_string[0].$sep." ".$date_string[1]." Y";
    if ( $_SESSION["MGW"]->settings["set_timefmt"] == "12h" ) {
      $date_format .= " g:i a";
    } else {
      $date_format .= " G:i";
    }
	$date_format .= " O";
    
    return( date_intl( $date_format, $stamp ) );
}

?>
